@@ -144,13 +144,12 @@ function SciMLBase.init(prob::LinearProblem, alg::HYPREAlgorithm,
     Tc = typeof(cacheval)
     isfresh = true
     precsisfresh = false
-
     cache = LinearCache{
         typeof(A), typeof(b), typeof(u0), typeof(p), typeof(alg), Tc,
-        typeof(Pl), typeof(Pr), typeof(reltol),
+        typeof(Pl), typeof(Pr), typeof(reltol), typeof(verb_spec),
         typeof(__issquare(assumptions)), typeof(sensealg)
     }(A, b, u0, p, alg, cacheval, isfresh, precsisfresh, Pl, Pr, abstol, reltol,
-        maxiters, verbose, assumptions, sensealg)
+        maxiters, verb_spec, assumptions, sensealg)
     return cache
 end
 
