@@ -63,6 +63,17 @@ function KrylovJL_GMRES(args...; kwargs...)
     KrylovJL(args...; KrylovAlg = Krylov.gmres!, kwargs...)
 end
 
+"""
+```julia
+KrylovJL_FGMRES(args...; gmres_restart = 0, window = 0, kwargs...)
+```
+
+A generic FGMRES implementation for square non-Hermitian linear systems
+"""
+function KrylovJL_FGMRES(args...; kwargs...)
+    KrylovJL(args...; KrylovAlg = Krylov.fgmres!, kwargs...)
+end
+
 """
 ```julia
 KrylovJL_BICGSTAB(args...; kwargs...)
@@ -338,3 +349,5 @@ function SciMLBase.solve!(cache::LinearCache, alg::KrylovJL; kwargs...)
     return SciMLBase.build_linear_solution(alg, cache.u, Ref(resid), cache;
         iters = stats.niter, retcode, stats)
 end
+
+update_tolerances_internal!(cache, alg::KrylovJL, atol, rtol) = nothing
